@@ -12,15 +12,15 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from netket.utils.types import DType
+from netket.utils.types import DType as _DType
 
-from netket.hilbert import AbstractHilbert
+from netket.hilbert import AbstractHilbert as _AbstractHilbert
 
 from ._local_operator import LocalOperator as _LocalOperator
 
 
 def destroy(
-    hilbert: AbstractHilbert, site: int, dtype: DType = float
+    hilbert: _AbstractHilbert, site: int, dtype: _DType = float
 ) -> _LocalOperator:
     """
     Builds the boson destruction operator :math:`\\hat{a}` acting on the `site`-th of
@@ -45,7 +45,9 @@ def destroy(
     return _LocalOperator(hilbert, mat, [site], dtype=dtype)
 
 
-def create(hilbert: AbstractHilbert, site: int, dtype: DType = float) -> _LocalOperator:
+def create(
+    hilbert: _AbstractHilbert, site: int, dtype: _DType = float
+) -> _LocalOperator:
     """
     Builds the boson creation operator :math:`\\hat{a}^\\dagger` acting on the `site`-th
     of the Hilbert space `hilbert`.
@@ -69,7 +71,9 @@ def create(hilbert: AbstractHilbert, site: int, dtype: DType = float) -> _LocalO
     return _LocalOperator(hilbert, mat, [site], dtype=dtype)
 
 
-def number(hilbert: AbstractHilbert, site: int, dtype: DType = float) -> _LocalOperator:
+def number(
+    hilbert: _AbstractHilbert, site: int, dtype: _DType = float
+) -> _LocalOperator:
     """
     Builds the number operator :math:`\\hat{a}^\\dagger\\hat{a}`  acting on the
     `site`-th of the Hilbert space `hilbert`.
@@ -94,7 +98,7 @@ def number(hilbert: AbstractHilbert, site: int, dtype: DType = float) -> _LocalO
 
 
 def proj(
-    hilbert: AbstractHilbert, site: int, n: int, dtype: DType = float
+    hilbert: _AbstractHilbert, site: int, n: int, dtype: _DType = float
 ) -> _LocalOperator:
     """
     Builds the projector operator :math:`|n\\rangle\\langle n |` acting on the
@@ -123,7 +127,3 @@ def proj(
     D[n] = 1
     mat = np.diag(D, 0)
     return _LocalOperator(hilbert, mat, [site], dtype=dtype)
-
-
-# clean up the module
-del AbstractHilbert, DType
